@@ -23,7 +23,7 @@ alfa.tune <- function(x, B = 1, ncores = 1) {
     -0.5 * n * log( abs( det( cov(z) ) ) ) + (a - 1) * sum( log(x) ) - D * trans$sa
   }
 
-  if (B == 1) {
+  if ( B == 1 ) {
     ell <- optimize(pa, c(-1, 1), x = x, maximum = TRUE )
     aff0 <- Compositional::alfa(x, 0)
     z0 <- aff0$aff
@@ -36,7 +36,7 @@ alfa.tune <- function(x, B = 1, ncores = 1) {
     ell <- optimize(pa, c(-1, 1), x = x, maximum = TRUE )
     ab <- numeric(B)
 
-    if (ncores == 1) {
+    if ( ncores == 1 ) {
       runtime <- proc.time()
       for (i in 1:B) {
         ind <- sample(1:n, n, replace = TRUE)
@@ -58,7 +58,8 @@ alfa.tune <- function(x, B = 1, ncores = 1) {
 
     param <- c(ell$maximum, ell$objective + con, quantile( ab, c(0.025, 0.975) ) )
     names(param)[1:2] <- c("best alpha", "max log-lik")
-    hist(ab, main = "Bootstrapped alpha values", xlab = expression( paste(alpha, " values", sep = "") ) )
+    hist( ab, main = "Bootstrapped alpha values", xlab = expression( paste(alpha, " values", sep = "") ),
+         cex.lab = 1.2, cex.axis = 1.2 )
     abline(v = ell$maximum, col = 3)
     abline(v = mean(ab), lty = 2, col = 4)
     message <- paste("The green is the best alpha value. The blue line is the bootstrap mean value of alpha.")
